import pandas, sys, argparse, re
import numpy as np

def count_skiplines(f):
    counter=0
    for n, line in enumerate(f):
        if line.startswith('##'):
            counter += 1
    return(counter)
            

def get_c(s):
    m= re.findall('chr(\d+)|.*',s)
    ss= str(m[0])
    if m[0] and ss.startswith('0'):
        ss= ss[1]
        i= int(ss)
        return i
    elif m[0]:
        return int(m[0])
    else:
        return 0

def get_reads(v, i, o, n):

    vcf= pandas.read_table(v, skiprows= n, na_values=['.']) 
    vcf['total_reads']= 0
    read_counter=0

    for row_idx, row in vcf.iterrows():

        key= (vcf.ix[row_idx, 'FORMAT']).split(':')
        ind= key.index("DP")

        for col_idx, col in row[9:len(row)-1].iteritems():
            lst= col.split(':')
            reads= int(lst[ind])
            read_counter += reads

        vcf.ix[row_idx, 'total_reads']= read_counter
        read_counter=0

    vcf['chrom']= vcf.ix[:,'#CHROM'].map(get_c)
    sub_reads= vcf[['chrom','POS','total_reads']]
    sub_reads=sub_reads.rename(columns={'POS':'pos','total_reads':'read_num'})

    grouped= sub_reads.groupby(['chrom','pos'],as_index=False)
    agg= grouped['read_num'].agg(np.sum)


    hmp= pandas.read_table(i)
    out= pandas.merge(hmp, agg, on=['chrom','pos'],how='left')
    out.to_csv(o, index=False, sep= '\t', na_rep="NA")
    

    
def main():
    parser= argparse.ArgumentParser(description="PLUMAGE v. 2.0: pipeline for GBS error correction")
    
    parser.add_argument('-v', metavar='vcf_file',
                        help= "PANATI .vcf file, required", required=True)

    parser.add_argument('-i', metavar= 'infile',  default= sys.stdin, nargs= '?', type=argparse.FileType('r'),
                        help= "input hapmap that you want to add reads to")

    parser.add_argument('-o', metavar= 'outfile', default= sys.stdout, nargs='?', type= argparse.FileType('w'),
                        help= "path/name of file you want hapmap with read numbers written to")

    args= parser.parse_args()
    nskip= count_skiplines(open(args.v))
    get_reads(open(args.v), args.i, args.o, nskip)

    print("Plumage 4 is finished", file= sys.stderr)

if __name__ == "__main__":
  main()
      

    

    



